var gphoto2_setting_8c =
[
    [ "Setting", "structSetting.html", "structSetting" ],
    [ "_BSD_SOURCE", "gphoto2-setting_8c.html#ad3d8a3bd0c0b677acef144f2c2ef6d73", null ],
    [ "CHECK_RESULT", "gphoto2-setting_8c.html#a1061828e4e2cafb14086ac2bed47f80d", null ],
    [ "gp_setting_get", "gphoto2-setting_8c.html#a4b50249c04f6a48156bad839827e67b7", null ],
    [ "gp_setting_set", "gphoto2-setting_8c.html#a6100f1cf5f3e90c2491807b6db1796af", null ]
];